@@ -34,7 +34,7 @@
 
       CALL USCSET('CXSIDE'  , 'T')
       CALL USCSET('CYSIDE'  , 'L')
-      CALL SWLGET('SYSFONT',LSFNT)
+      CALL SWLGET('LSYSFNT',LSFNT)
       CALL USSTTL('TEMPERATURE', '\^'//USGI(228)//'C', 'DEPTH', 'm')
       CALL USGRPH(N, T, Z)
 
