@@ -55,7 +55,7 @@
         WRITE(CHR,'(I5)') ITPAT
         CALL SGIGET('IBGCLI',IBC)
         IF(ITPAT.EQ.999)THEN
-          ITPAT=IBC*1000 + 999
+*          ITPAT=IBC*1000 + 999
         ENDIF
 
         CALL SLPVPR( 1 )
