@@ -1,9 +1,9 @@
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       PROGRAM DCLFNT
 
-      CHARACTER CH*3,CSGI*1,CTTL*16
+      CHARACTER CH*3,USGI*3,CTTL*16
 
 
       CALL SWISTX('IWIDTH ',600)
@@ -37,7 +37,7 @@
       DO 15 I=0,255
         UX=I/16+0.5
         UY=16-MOD(I,16)-0.5
-        CALL SGTXZU(UX,UY,CSGI(I),0.035,0,0,3)
+        CALL SGTXZU(UX,UY,USGI(I),0.035,0,0,3)
         UX=UX+0.48
         UY=UY+0.38
         WRITE(CH,'(I3)') I
