@@ -4,9 +4,7 @@
       PROGRAM SGFNDL
 
       CHARACTER FONTNAME*1024,CTEXT*1024
-
-      EXTERNAL  LENC,ISGC
-
+      CHARACTER CSGI*1,NTEXT*1
 
       CALL SGOPN(1)
       CALL SGFRM
@@ -19,8 +17,10 @@
       CALL SWLSET('LSYSFNT', .TRUE.)
 
       CALL SWSLFT(FONTNAME)
-      CTEXT='Selected font name: '//FONTNAME
+      NTEXT=CSGI(0)
+      CTEXT='Selected font name: '//FONTNAME//NTEXT
       CALL SGTXZV(0.5, 0.50, CTEXT, 0.04, 0, 0, 3)
+
       CTEXT='(This is drawn by DCL defalt system font)'
       CALL SGTXZV(0.5, 0.45, CTEXT, 0.03, 0, 0, 3)
 
