@@ -56,13 +56,15 @@
       IF (IWS.EQ.1 .OR. IWS.EQ.2) THEN
         CALL SWIGET('IWIDTH ', IWIDTH)
         CALL SWIGET('IHEIGHT', IHEIGH)
-        CALL SWIGET('ICLRMAP', ICLRMP)
         CALL SWLGET('LFGBG  ', LFGBG )
         CALL SWCGET('FNAME  ', COUT  )
         CALL SWCGET('TITLE  ', CTTL  )
         CALL SWIGET('IDMPDGT ', IDMPDGT)
         CALL SWIGET('IBGPAGE ',IBGPAGE)
+        CALL SWIGET('ICLRMAP', ICLRMP)
         CALL SWCMLL
+        CALL SWQCMF(ICLRMP   , CLRMAP)
+        CALL SWCSET('CLRMAP' , CLRMAP)
         CALL SWQFNM('CLRMAP ', CLRMAP)
         CALL GLCGET('DSPATH',  DSPATH)
 
@@ -125,13 +127,12 @@
      +       LFGBG,LSEP,IFL,CIMGFMT, RIMGCMP, CLRMAP, CBTMAP, COUT,
      +       CTTL)
 
+
         IF (CLRMAP.EQ.(DSPATH(1:LENC(DSPATH))//'colormap.x11')) THEN
           CALL SWQCMF(ICLRMP,CMAP)
           CALL SWCSET('CLRMAP ',CMAP)
         END IF
 
-
-
       LOPEN = .TRUE.
 
       RETURN
