@@ -7,7 +7,7 @@
 
       CHARACTER CP*(*)
 
-      PARAMETER (NPARA = 21)
+      PARAMETER (NPARA = 27)
 
       INTEGER   ITYPE(NPARA)
       CHARACTER CPARAS(NPARA)*8
@@ -42,7 +42,13 @@
       DATA      CPARAS(18) / 'NLNSIZE ' / , ITYPE(18) / 1 /
       DATA      CPARAS(19) / 'ICLRMAP ' / , ITYPE(19) / 1 /
       DATA      CPARAS(20) / 'LFGBG   ' / , ITYPE(20) / 2 /
-      DATA      CPARAS(21) / 'SYSFONT ' / , ITYPE(21) / 2 /
+      DATA      CPARAS(21) / 'LSYSFNT ' / , ITYPE(21) / 2 /
+      DATA      CPARAS(22) / 'IDMPDGT ' / , ITYPE(22) / 1 /
+      DATA      CPARAS(23) / 'MAXFNU  ' / , ITYPE(23) / 1 /
+      DATA      CPARAS(24) / 'IFL     ' / , ITYPE(24) / 1 /
+      DATA      CPARAS(25) / 'IBGPAGE ' / , ITYPE(25) / 1 /
+      DATA      CPARAS(26) / 'LCMCH   ' / , ITYPE(26) / 2 /
+      DATA      CPARAS(27) / 'LSTDOT  ' / , ITYPE(27) / 2 /
 
 *     / LONG NAME /
 
@@ -67,6 +73,12 @@
       DATA      CPARAL(19) / 'COLORMAP_NUMBER' /
       DATA      CPARAL(20) / '****LFGBG   ' /
       DATA      CPARAL(21) / 'USE_SYSTEM_FONT' /
+      DATA      CPARAL(22) / 'DMPFILE_DIGITS' /
+      DATA      CPARAL(23) / '****MAXFNU  ' /
+      DATA      CPARAL(24) / '****IFL     ' /
+      DATA      CPARAL(25) / 'BEGIN PAGE  ' / 
+      DATA      CPARAL(26) / 'CMAP_CHANGABLE' /
+      DATA      CPARAL(27) / 'PNG_STDOUT' /
 
       NCP = NPARA
 
