@@ -23,10 +23,6 @@
 
 static DCL_REAL rwxold, rwyold;
 
-#ifndef M_PI
-#define M_PI  3.14159265358979323846 /* pi */
-#endif
-
 #define FACTZ  0.03          /* scaling factor */
 
 #ifndef TRUE
@@ -304,7 +300,7 @@ void ZGIINT(DCL_INT *iwx, DCL_INT *iwy, DCL_REAL *wx, DCL_REAL *wy)
 #if GTKVERSION==2
 void zgupdate(int flag)
 #else
-void zgupdate(int flag,cairo_t* cr )
+void zgupdate(int flag,cairo_t* crx )
 #endif
 {
 #if GTKVERSION==2
@@ -320,6 +316,7 @@ void zgupdate(int flag,cairo_t* cr )
       update_rect.width  = wsxwd;
       update_rect.height = wsywd;
     }
+  gtk_widget_draw(drawing_area, &update_rect);
 #else
   GtkAllocation update_rect;
   if (idev_type==IWS_DISP){
@@ -329,17 +326,17 @@ void zgupdate(int flag,cairo_t* cr )
     update_rect.height = iryt-iryb+1;
     if (irxb == 0 && irxt == 0 && iryb == 0 && iryt == 0 && flag == 0){
       update_rect.x = 0;
-      update_rect.y = 0;
+      update_rect.x = 0;
       update_rect.width  = wsxwd-1;
       update_rect.height = wsywd-1;
     }
 #endif
-
 #if GTKVERSION==2
-      gtk_widget_draw(drawing_area, &update_rect);
 #else
-      gtk_widget_size_allocate(drawing_area, &update_rect);
-      gtk_widget_draw(drawing_area, cr);
+      gtk_widget_queue_draw_area(
+        drawing_area,
+        update_rect.x,update_rect.y,
+        update_rect.width,update_rect.height);
 #endif
       irxt = 0;
       irxb = 0;
@@ -533,8 +530,8 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
     }
       gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK|GDK_KEY_PRESS_MASK);
 #if GTKVERSION==2
-      gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK);
-      gtk_signal_connect(GTK_OBJECT (window), "button_press_event",
+    gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK);
+    gtk_signal_connect(GTK_OBJECT (window), "button_press_event",
   		       (GtkSignalFunc) zg_button_press_event, NULL);
     gtk_widget_set_events(drw, GDK_EXPOSURE_MASK);
     gtk_signal_connect(GTK_OBJECT (drw), "expose_event",
@@ -543,13 +540,13 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
   		       (GtkSignalFunc) zg_destroy_event, NULL);
 #else
 //      gtk_widget_set_events(drw, GDK_EXPOSURE_MASK);
-      gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK);
-      g_signal_connect(G_OBJECT(window), "key_press_event",
-                          G_CALLBACK(zg_key_press_event), NULL);
+    gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK);
+    g_signal_connect(G_OBJECT(window), "key_press_event",
+                      G_CALLBACK(zg_key_press_event), NULL);
     g_signal_connect (G_OBJECT(drw), "draw",
                       G_CALLBACK(zg_draw_event), NULL);
     g_signal_connect(G_OBJECT (window), "destroy",
-  		      G_CALLBACK(zg_destroy_event), NULL);
+  	          	      G_CALLBACK(zg_destroy_event), NULL);
 #endif
       gtk_widget_show(window);
   }
@@ -1018,7 +1015,7 @@ void ZGPCLS(void)
 #if GTKVERSION==2
       zgupdate(0);
 #else
-      zgupdate(0,cr);
+    gtk_widget_queue_draw(drawing_area);
 #endif
     }
     if (wait_np) {
@@ -1229,7 +1226,6 @@ void ZGGMOV(DCL_REAL *wx, DCL_REAL *wy)
   rwxold = *wx;
   rwyold = *wy;
   zguprect(rwx,rwy);
-
 }
 
 
@@ -1976,7 +1972,7 @@ void ZGTXT(DCL_REAL *wx, DCL_REAL *wy, DCL_REAL *size, char* text, DCL_INT *len,
   if (jdev_type > 0) {
     rotation = -*irota;
   }else{
-    rotation = -*irota + M_PI/2;
+    rotation = -*irota + G_PI/2;
   }
 
   /* centering, left-/right-aligned*/
@@ -2206,14 +2202,12 @@ void ZGFONTNAME(DCL_INT *n, char* string, DCL_INT *nmax)
 
     fontmap = pango_cairo_font_map_get_default();
     pango_font_map_list_families (fontmap, & families, & n_families);
-//    printf ("There are %d families\n", n_families);
     i = *n;
     PangoFontFamily * family = families[i];
     const char * family_name;
 
     family_name = pango_font_family_get_name (family);
     printf ("Family %d: %s\n", i, family_name);
-//    sprintf(string, "%s", family_name);
     for (i=0; i<strlen(family_name);i++){
       string[i] = family_name[i];
     }
@@ -2405,8 +2399,6 @@ void ZGIDAT(DCL_INT image[], DCL_INT *nlen)
       }
     }
   }
-//  if(!laltz){zgupdate(1);}
-////  cairo_set_antialias(cr,CAIRO_ANTIALIAS_DEFAULT);
 }
 
 #ifndef WINDOWS
