@@ -1,5 +1,5 @@
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE SZTXOP(RSIZE,IROTA,ICENT,INDEX)
 
@@ -16,7 +16,7 @@
       SAVE
 
 
-*     CALL SGIGET('IFONT',IFONT)
+      CALL SGIGET('IFONT',IFONT)
 
       QSIZE=RSIZE/WIDE
       THETA=RD2R(REAL(IROTA))
@@ -41,8 +41,8 @@
       CALL SZQIDX(INDEXZ)
       CALL SZSIDX(INDEX)
 
-*     WRITE(COBJ,'(F8.5,5I8)') RSIZE,IROTA,ICENT,INDEX,IFONT,IWS
-      WRITE(COBJ,'(F8.5,5I8)') RSIZE,IROTA,ICENT,INDEX,IWS
+      WRITE(COBJ,'(F8.5,5I8)') RSIZE,IROTA,ICENT,INDEX,IFONT,IWS
+*     WRITE(COBJ,'(F8.5,5I8)') RSIZE,IROTA,ICENT,INDEX,IWS
       CALL CDBLK(COBJ)
       CALL SWOOPN('SZTX',COBJ)
 
