@@ -1,7 +1,7 @@
 *-----------------------------------------------------------------------
 *     UDCNTZ
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE UDCNTZ(Z,MX,NX,NY,IBR,NBR2)
 
@@ -10,7 +10,7 @@
 
       INTEGER   NS(2),NP(2),NQ(2)
       LOGICAL   LUDCHK,LOPEN,LMISS,LMADA,LOK,LSET,LMSG,
-     +          LEPSL,LCHAR,LMAP,LCLIP,LPRINT,LEXIT
+     +          LEPSL,LCHAR,LMAP,LCLIP,LPRINT,LEXIT,LCENT
       CHARACTER CMSG*80
 
       COMMON    /UDBLK1/ NB,LX,LY,NBR
@@ -31,6 +31,7 @@
       CALL UDRGET('RSIZET  ',RSIZE )
       CALL UDRGET('XTTL    ',XTTL  )
       CALL UDLGET('LMSG    ',LMSG  )
+      CALL UDLGET('LCENT   ',LCENT )
       CALL UDIGET('NLEV    ',NLEV  )
       CALL UDIGET('INDXMJ  ',INDEX )
 
@@ -141,7 +142,7 @@
         CALL SGLSET('LCLIP',.FALSE.)
         CALL SGQVPT(VXMN,VXMX,VYMN,VYMX)
         XPT=(VXMN+VXMX)/2
-        IF (LMAP) THEN
+        IF (LMAP.AND.LCENT) THEN
           YPT=VYMN/2
         ELSE
           CALL UZRGET('ROFFXB',ROFFX)
@@ -228,10 +229,11 @@
               ELSE
                 ZZ2=Z(IX,IY1)
               END IF
-              IF ((ZZ1-CX)*(ZZ2-CX).LT.0
-     +            .AND. LUDCHK(IX,IY,K,1,IBR)) THEN
-                CALL UDBSET(IX,IY,K,0,IBR)
-                NN=NN+1
+              IF (LUDCHK(IX,IY,K,1,IBR)) then
+                if ((ZZ1-CX)*(ZZ2-CX).LT.0) THEN
+                  CALL UDBSET(IX,IY,K,0,IBR)
+                  NN=NN+1
+                end if
               END IF
    70       CONTINUE
    65     CONTINUE
