@@ -1,7 +1,7 @@
 *-----------------------------------------------------------------------
 *     SCATTERED POINTS
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE UMSPNT(N, UX, UY)
 
@@ -30,8 +30,8 @@
 *-----------------------------------------------------------------------
       ENTRY UMQPNT(N, UXA, UYA)
 
-      UXA = UX(N)
-      UYA = UY(N)
+      UXA = UXZ(N)
+      UYA = UYZ(N)
 
       RETURN
 *-----------------------------------------------------------------------
