@@ -1,10 +1,12 @@
 *-----------------------------------------------------------------------
 *     UYPLBA : PLOT LABELS ( AT THE POINTS )
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE UYPLBA(UY,CH,NC,N,UPX,ROFFY,RSIZE,IROTA,ICENT,INDEX)
 
       REAL      UY(*)
-      CHARACTER CH*(*)
+      CHARACTER CH(*)*(*)
 
       LOGICAL   LCLIPZ
 
@@ -31,12 +33,10 @@
 
       CALL SZTXOP(RSIZE,IROTA*90,ICENT,INDEX)
       DO 10 I=1,N
-        I1=NC*(I-1)+1
-        I2=NC*I
-        LC=LENC(CH(I1:I2))
+        LC = LENC(CH(I))
         CALL STFTRF(UPX,UY(I),VPX,VPY)
         VPX=VPX+ROFFY
-        CALL SZTXZV(VPX,VPY,CH(I1:I1+LC-1))
+        CALL SZTXZV(VPX,VPY,CH(I)(1:LC))
    10 CONTINUE
       CALL SZTXCL
 
